@@ -5,7 +5,7 @@ use lib 'inc';
 
 use Test::Base -Base;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Data::Dumper;
 use Time::HiRes qw(sleep time);
@@ -35,6 +35,9 @@ use Test::Nginx::Util qw(
     master_process_enabled
     config_preamble
     repeat_each
+    workers
+    master_on
+    log_level
 );
 
 #use Smart::Comments::JSON '###';
@@ -44,9 +47,13 @@ use IO::Socket;
 
 #our ($PrevRequest, $PrevConfig);
 
+our $NoLongString = undef;
+
 our @EXPORT = qw( plan run_tests run_test
     repeat_each config_preamble worker_connections
-    master_process_enabled);
+    master_process_enabled
+    no_long_string workers master_on
+    log_level);
 
 sub send_request ($$$);
 
@@ -56,6 +63,10 @@ sub error_event_handler ($);
 sub read_event_handler ($);
 sub write_event_handler ($);
 
+sub no_long_string () {
+    $NoLongString = 1;
+}
+
 $RunTestHelper = \&run_test_helper;
 
 sub parse_request ($$) {
@@ -204,7 +215,7 @@ $parsed_req->{content}";
 
         my $decoded = '';
         while (1) {
-            if ($raw =~ /\G 0 [\ \t]* \r\n \r\n $/gcsx) {
+            if ($raw =~ /\G 0 [\ \t]* \r\n \r\n /gcsx) {
                 last;
             }
             if ($raw =~ m{ \G [\ \t]* ( [A-Fa-f0-9]+ ) [\ \t]* \r\n }gcsx) {
@@ -290,8 +301,12 @@ $parsed_req->{content}";
         $expected =~ s/\$ServerPortForClient\b/$ServerPortForClient/g;
         #warn show_all_chars($content);
 
-        is_string($content, $expected, "$name - response_body - response is expected");
-        #is($content, $expected, "$name - response_body - response is expected");
+        #warn "no long string: $NoLongString";
+        if ($NoLongString) {
+            is($content, $expected, "$name - response_body - response is expected");
+        } else {
+            is_string($content, $expected, "$name - response_body - response is expected");
+        }
 
     } elsif (defined $block->response_body_like) {
         my $content = $res->content;
@@ -684,6 +699,14 @@ L<http://wiki.nginx.org/NginxHttpMemcModule>
 
 L<http://github.com/chaoslawful/drizzle-nginx-module>
 
+=item ngx_rds_json
+
+L<http://github.com/agentzh/rds-json-nginx-module>
+
+=item ngx_xss
+
+L<http://github.com/agentzh/xss-nginx-module>
+
 =back
 
 =head1 SOURCE REPOSITORY
